classdef BranchManager < handle
    %BRANCHMANAGER Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        branchlist
        selection
        
    end
    
    properties(Constant)
       DF = DefaultCurve(); 
        
    end
    
    events
       newlist 
       selectionChanged
    end
    
    
    methods
        
        function obj = BranchManager(session)
            obj.clean();
            
            if (nargin > 0)
               session.addlistener('newSystem' , @(o,e) obj.clean()); 
            end
            
        end
        
        %FIXME: messy,  pointdata verspreid over meerdere files
        function setup(obj, session)
            pointtype = session.getPointType().getLabel();
            
	    parrentcurvetype = session.getCurrentCurve().getParentCT(); %may be empty string
            
            obj.selection = -1;
            clist = CurveType.getList();
            
            printc(mfilename, ['pointtype is ' pointtype]);
            
            obj.branchlist = {};
            
            defaultbranchlabel = obj.DF.retrieveDefaultCurve(pointtype, parrentcurvetype);
            printc(mfilename , ['default init: ' defaultbranchlabel ]); 
            
            
            for i = 1:length(clist)
                obj.branchlist = [ obj.branchlist  clist{i}.getBranches( pointtype )];
            end

            
                if (~strcmp(defaultbranchlabel , obj.DF.NOTHING))
                    i = 1;
                    blen = length(obj.branchlist);  %can be zero

                    while ((i <= blen) && (~strcmp(defaultbranchlabel, obj.branchlist{i}.getLabel()))) 
                       i  = i+1; 
                    end

                    if ( i <= blen)
                        printc(mfilename , ['branch found: ' obj.branchlist{i}.toString() ]);
                        obj.select(session, i);
                    end
                end
           obj.notify('newlist');
           session.notify('stateChanged');
        end
        
        
        
        function clean(obj)
            obj.selection = -1;
            obj.branchlist = {};
            obj.notify('newlist');
            obj.notify('selectionChanged');
        end
        function nr = getNr(obj)
            nr = length(obj.branchlist);
        end
        function list = getList(obj)
           list = obj.branchlist; 
        end
        
        function select(obj,session,index)
            obj.selection = index;
            b = obj.getCurrentBranch();
            
            if (~isempty(b))
               starter =  session.getStartData();
               session.setCurveType( b.getCurveType() );
               
               amp_enabled = strcmp(b.getType(),'SH') || strcmp(b.getType(),'eps');
               printc(mfilename, 'setting amplitude enabled: %d' , amp_enabled);
               
               starter.setEnabled('amplitude' , amp_enabled);
               starter.notify('structureChanged');
               
               session.notify('stateChanged');
               obj.notify('selectionChanged');
            end
        end
        function i = getSelectionIndex(obj)
            i = obj.selection;
        end
        function bool = validSelectionMade(obj)
           bool =  ((obj.selection >= 1) &&  (obj.selection <= obj.getNr()));
        end
        
        function b = getCurrentBranch(obj)
            if((obj.selection >= 1) &&  (obj.selection <= obj.getNr()))
                b =  obj.branchlist{ obj.selection };
            else
               b =  [];
            end
        end
        function str = getCurrentInfo(obj)
            if((obj.selection >= 1) &&  (obj.selection <= obj.getNr()))
                b =  obj.branchlist{ obj.selection };
                str = b.toString();
            else
               str =  '';
            end
            
        end                

        function newn = getNewIterationN(obj, n)
             b = obj.getCurrentBranch();
             newn = n * b.getPeriodMult();
        end
        
        function [x0,v0] = performInit(obj,session , curve, x0 , par , systemhandle , n)
            branch = getCurrentBranch(obj);
            if (isempty(branch))
                errordlg('no curve selected' , 'error');
                x0 = []; v0 = []; return;
            end
            
            ap = session.starterdata.getActiveParams();
            
            switch (branch.getType)
                case 'D'
                    [x0,v0] = callInit(branch, systemhandle, x0, par, ap, n);
                case 'eps'
                    amplitude_eps = session.starterdata.getSetting('amplitude');
                    [x0,v0] = callInit(branch, systemhandle, amplitude_eps, x0, par, ap, n); 
                case 'SH'
                    amplitude_h =  session.starterdata.getSetting('amplitude');
                    [x0,v0] = callInit(branch, systemhandle, x0, par, curve.startpoint, amplitude_h, n); 
                otherwise
                    error('otherwise happended');
            end
            
        end

        
        
    end
end

function [x0,v0] = callInit(branch, varargin)
    init = branch.getInitFunc();
    printc(mfilename , ['Call ' func2str(init) '  ']); %disp(varargin);
    
    if (branch.isConditional())
       [x0,v0,accepted] = init(false, varargin{:}); 
       if (~accepted)
            errordlg([branch.toString() ': Condition failed!'], 'condition failed'); 
       end
    else
       [x0,v0] = init(varargin{:}); 
    end
end
