classdef ContDataModel < handle
    % Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        continuation
        corrector
        stop

        backwards = 0;
        
        frozen = 0;
    end
    
    events
       settingChanged 
    end
    
    methods
        function obj = ContDataModel(varargin)
            obj.continuation.InitStepSize = 0.01;
            obj.continuation.MinStepSize = 1e-5;
            obj.continuation.MaxStepSize = 0.1;
            
            obj.corrector.MaxNewtonIters = 3;
            obj.corrector.MaxCorrIters = 10;
            obj.corrector.TestIters = 10;
            obj.corrector.VarTolerance = 1e-06;
            obj.corrector.FunTolerance = 1e-06;
            obj.corrector.TestTolerance = 1e-05;
            obj.corrector.Adapt = 1;
            
            obj.stop.MaxNumPoints = 300;
            obj.stop.ClosedCurve = 50;
            
            if (nargin >= 1)
                obj.frozen = varargin{1};
            end
        end
        
        function copyOver(obj,contdata)
           obj.continuation = contdata.continuation;
           obj.corrector = contdata.corrector;
           obj.stop  = contdata.stop;
           obj.notify('settingChanged');
        end
        function A = saveobj(obj)
           A.continuation = obj.continuation;
           A.corrector = obj.corrector;
           A.stop  = obj.stop;
        end   
        
        
        function list = getContinuationDataList(obj)
            list = fieldnames(obj.continuation);
        end
        
        function setContinuationData(obj , key , val)
            if (~isempty(val))
            obj.continuation.(key) = val;
            end
        end

        function val= getContinuationData(obj,key)
                val = obj.continuation.(key);
        end
        
        function setBackwards(obj, backwards)
           if (~isempty(backwards)), obj.backwards = backwards; end 
        end
        function val = getBackwards(obj)
            val = obj.backwards;
        end
        
	
	function list = getCorrectorDataList(obj)
            list = fieldnames(obj.corrector);
        end
        
        function setCorrectorData(obj , key , val)
            if (~isempty(val))
                obj.corrector.(key) = val;
            end
        end

        function val= getCorrectorData(obj,key)
            val = obj.corrector.(key);
        end
        
	
	
	function list = getStopDataList(obj)
            list = fieldnames(obj.stop);
        end
        
        function setStopData(obj , key , val)
            if (~isempty(val))
                obj.stop.(key) = val;
            end
        end

        function val= getStopData(obj,key)
            val = obj.stop.(key);
        end
        function b = isFrozen(obj)
           b = obj.frozen; 
        end

    end
    
end

