classdef SessionData < handle
    %SESSIONDATA Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        filepath
        data
    end
    
    methods
        function obj = SessionData(filepath)
            obj.filepath = filepath;
            if (exist(filepath, 'file'))
                try
                    load(filepath);
                    if (exist('data','var'))
                        printc(mfilename,['loaded data from ' filepath]); 
                        obj.data = data;
                    else
                        printc(mfilename,['filename exists, no data: ' filepath]);
                        obj.data = []; 
                    end
                catch ME
                    printc(mfilename, ME.message);
                    obj.data = [];
                    
                end
                
            else
                obj.data = [];
                
            end
            
            obj.initSwitch();
        end
        
        function recordState(obj, session)
           if(session.hasSystem())
                state = struct();
                state.system = session.getSystem().getName();
                state.diagram = session.getCurveManager().getDiagramName();
                
                c = session.getCurrentCurve();
                state.currentcurve = [];
                
                
                if (c.hasFile())
                   state.curvename = c.getLabel(); 
                else
                   state.curvename = []; 
                end
                
                state.curve = c.saveobj();
                state.startdata = session.getStartData().saveobj();
                state.contdata  = session.getContData().saveobj();
                state.numdata = session.numericdata.saveobj();
                state.plotdata = session.plotmanager.saveobj();
                 
                state.branchselection = session.branchmanager.getSelectionIndex();
                
                obj.data.state = state;
           else
                obj.data.state = []; 
           end
           
        end
        
        
        function restoreState(obj, session) 
            if (~obj.data.opt.restorestate) , return; end;
            if (isfield(obj.data, 'state') && ~isempty(obj.data.state))
               state = obj.data.state;
               try
               sys = SystemSpace.loadSystem(session , state.system);
               catch ME
                  printc(mfilename, ME.message);
                  obj.data.state = [];
                  return;
               end
               % sys loaded
               dlist = InspectorDiagram.getDiagramList( sys.getPath());
               if (ismember(state.diagram , dlist))
                   dpath = [sys.getPath() '/' state.diagram];
               else 
                  sys.setUp(); 
                  dpath = sys.getDefaultDiagramPath();
               end
               cm = CurveManager(session , dpath);
               
               if (isempty(state.curvename) || ~cm.curveExist(state.curvename))
                   curve = cm.getBlankCurve(obj);
                   curve.loadIn(state.curve);
                   
               else
                  curve =  cm.loadCurveFromMemory( state.curvename , state.curve );
               end
               
               
               session.changeCurve(sys  ,  cm, curve, state.startdata , state.contdata);

                  session.branchmanager.select(session ,  state.branchselection );

               
               session.numericdata.copyOver(state.numdata);
               session.plotmanager.loadIn(session, state.plotdata);
               
            end
        end
        
        
        
        function saveData(obj)
            data = obj.data;
            save(obj.filepath,'data');            
        end

        
        function bool = getSwitch(obj , switchname)
              bool = obj.data.opt.(switchname);
        end
        function setSwitch(obj, switchname , bool)
            obj.data.opt.(switchname) = bool;
        end
        
        function initSwitch(obj)
           if (~isfield(obj.data, 'opt'))
               obj.data.opt.restorestate = 1;
               obj.data.opt.popup = 1;
               obj.data.opt.debug = 0;
               obj.data.opt.autoredraw = 0;
               obj.data.opt.autofit = 0;
           end
                        
        end
        
        
        
    end
    
end

